API exported by pygame.cdrom — pygame v2.1.1 documentation

##### pygame documentation | Pygame Home || Help Contents || Reference Index Most useful stuff: Color | display | draw | event | font | image | key | locals | mixer | mouse | Rect | Surface | time | music | pygame Advanced stuff: cursors | joystick | mask | sprite | transform | BufferProxy | freetype | gfxdraw | midi | PixelArray | pixelcopy | sndarray | surfarray | math Other: camera | controller | examples | fastevent | scrap | tests | touch | version

## src_c/cdrom.c

The `pygame.cdrom`pygame module for audio cdrom control extension module. Only available for SDL 1.

Header file: src_c/include/pygame.h

type pgCDObject

  The `pygame.cdrom.CD` instance C struct.

PyTypeObject pgCD_Type

  The `pygame.cdrom.CD` Python type.

PyObject *pgCD_New(int id)

  Return a new `pygame.cdrom.CD` instance for CD drive id. On error raise a Python exception and return `NULL`.

int pgCD_Check(PyObject *x)

  Return true if x is a `pygame.cdrom.CD` instance. Will return false for a subclass of `CD`. This is a macro. No check is made that x is not `NULL`.

int pgCD_AsID(PyObject *x)

  Return the CD identifier associated with the `pygame.cdrom.CD` instance x. This is a macro. No check is made that x is a `pygame.cdrom.CD` instance or is not `NULL`.

Edit on GitHub